@@ -50,6 +50,8 @@ BackupVaultEventType = Literal[
     "RESTORE_JOB_FAILED",
     "RESTORE_JOB_STARTED",
     "RESTORE_JOB_SUCCESSFUL",
+    "S3_BACKUP_OBJECT_FAILED",
+    "S3_RESTORE_OBJECT_FAILED",
 ]
 ConditionTypeType = Literal["STRINGEQUALS"]
 CopyJobStateType = Literal["COMPLETED", "CREATED", "FAILED", "RUNNING"]
