@@ -47,7 +47,9 @@ __all__ = (
     "BackupSelectionsListMemberTypeDef",
     "BackupVaultListMemberTypeDef",
     "CalculatedLifecycleTypeDef",
+    "ConditionParameterTypeDef",
     "ConditionTypeDef",
+    "ConditionsTypeDef",
     "ControlInputParameterTypeDef",
     "ControlScopeTypeDef",
     "CopyActionTypeDef",
@@ -346,6 +348,8 @@ _OptionalBackupSelectionTypeDef = TypedDict(
     {
         "Resources": Sequence[str],
         "ListOfTags": Sequence["ConditionTypeDef"],
+        "NotResources": Sequence[str],
+        "Conditions": "ConditionsTypeDef",
     },
     total=False,
 )
@@ -394,6 +398,15 @@ CalculatedLifecycleTypeDef = TypedDict(
     total=False,
 )
 
+ConditionParameterTypeDef = TypedDict(
+    "ConditionParameterTypeDef",
+    {
+        "ConditionKey": str,
+        "ConditionValue": str,
+    },
+    total=False,
+)
+
 ConditionTypeDef = TypedDict(
     "ConditionTypeDef",
     {
@@ -403,6 +416,17 @@ ConditionTypeDef = TypedDict(
     },
 )
 
+ConditionsTypeDef = TypedDict(
+    "ConditionsTypeDef",
+    {
+        "StringEquals": Sequence["ConditionParameterTypeDef"],
+        "StringNotEquals": Sequence["ConditionParameterTypeDef"],
+        "StringLike": Sequence["ConditionParameterTypeDef"],
+        "StringNotLike": Sequence["ConditionParameterTypeDef"],
+    },
+    total=False,
+)
+
 ControlInputParameterTypeDef = TypedDict(
     "ControlInputParameterTypeDef",
     {
@@ -866,6 +890,7 @@ DescribeRegionSettingsOutputTypeDef = TypedDict(
     "DescribeRegionSettingsOutputTypeDef",
     {
         "ResourceTypeOptInPreference": Dict[str, bool],
+        "ResourceTypeManagementPreference": Dict[str, bool],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -1990,6 +2015,7 @@ UpdateRegionSettingsInputRequestTypeDef = TypedDict(
     "UpdateRegionSettingsInputRequestTypeDef",
     {
         "ResourceTypeOptInPreference": Mapping[str, bool],
+        "ResourceTypeManagementPreference": Mapping[str, bool],
     },
     total=False,
 )
